@@ -5,6 +5,7 @@ from pathlib import Path
 import configparser
 from hashlib import sha1
 import json
+import warnings
 
 
 def read_cache_json(cache_key):
@@ -98,6 +99,19 @@ def generate_process_cred_json(credential_data):
     }
 
 
+def call_sts_get_caller_identity(profile_name):
+    # Altho we have an sso session, we might not have the cli cache. The first aws call generates it, so we call get-caller-identity.
+    # This only happens if the cache file is missing, as it takes a few moments.
+    sts_call_result = subprocess.check_output(f'aws sts get-caller-identity --profile {profile_name}', shell=True, universal_newlines=True)
+    try:
+        sts_call_data = json.loads(sts_call_result)
+        logged_in_arn = sts_call_data['Arn']
+        print(f'AWSHELPER: Generated cli cache. Logged in as {logged_in_arn}')
+    except:
+        pass
+    return
+
+
 def main():
     profile_name, profile_param_length = get_profile_name(sys.argv)
     if not profile_name:
@@ -111,7 +125,14 @@ def main():
     try:
         cache_data = read_cache_json(cache_key)
     except Exception:
-        sys.exit(f'Unable to read cache file generated by aws cli. Try running aws configure sso --profile {profile_name}')
+        #sys.exit(f'Unable to read cache file generated by aws cli. Try running aws configure sso --profile {profile_name}')
+        print(f'AWSHELPER: Credentials file not found. Executing aws sts get-caller-identity --profile {profile_name} to generate it')
+        call_sts_get_caller_identity(profile_name)
+
+    try:
+        cache_data = read_cache_json(cache_key)
+    except Exception:
+        sys.exit(f'AWSHELPER: Unable to read cache file generated by aws cli. You might not be logged in (run aws configure sso --profile {profile_name}')
     if is_external_process_mode():
         print(json.dumps(generate_process_cred_json(cache_data), indent=4, sort_keys=True))
         exit(0)
